@@ -1,7 +1,7 @@
 """
 Type annotations for keyspaces service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_keyspaces/type_defs/)
 
 Usage::
 
@@ -80,24 +80,50 @@ __all__ = (
     "UpdateTableResponseTypeDef",
 )
 
-CapacitySpecificationSummaryTypeDef = TypedDict(
-    "CapacitySpecificationSummaryTypeDef",
+_RequiredCapacitySpecificationSummaryTypeDef = TypedDict(
+    "_RequiredCapacitySpecificationSummaryTypeDef",
     {
         "throughputMode": ThroughputModeType,
-        "readCapacityUnits": NotRequired[int],
-        "writeCapacityUnits": NotRequired[int],
-        "lastUpdateToPayPerRequestTimestamp": NotRequired[datetime],
     },
 )
+_OptionalCapacitySpecificationSummaryTypeDef = TypedDict(
+    "_OptionalCapacitySpecificationSummaryTypeDef",
+    {
+        "readCapacityUnits": int,
+        "writeCapacityUnits": int,
+        "lastUpdateToPayPerRequestTimestamp": datetime,
+    },
+    total=False,
+)
 
-CapacitySpecificationTypeDef = TypedDict(
-    "CapacitySpecificationTypeDef",
+
+class CapacitySpecificationSummaryTypeDef(
+    _RequiredCapacitySpecificationSummaryTypeDef, _OptionalCapacitySpecificationSummaryTypeDef
+):
+    pass
+
+
+_RequiredCapacitySpecificationTypeDef = TypedDict(
+    "_RequiredCapacitySpecificationTypeDef",
     {
         "throughputMode": ThroughputModeType,
-        "readCapacityUnits": NotRequired[int],
-        "writeCapacityUnits": NotRequired[int],
     },
 )
+_OptionalCapacitySpecificationTypeDef = TypedDict(
+    "_OptionalCapacitySpecificationTypeDef",
+    {
+        "readCapacityUnits": int,
+        "writeCapacityUnits": int,
+    },
+    total=False,
+)
+
+
+class CapacitySpecificationTypeDef(
+    _RequiredCapacitySpecificationTypeDef, _OptionalCapacitySpecificationTypeDef
+):
+    pass
+
 
 ClusteringKeyTypeDef = TypedDict(
     "ClusteringKeyTypeDef",
@@ -122,13 +148,26 @@ CommentTypeDef = TypedDict(
     },
 )
 
-CreateKeyspaceRequestRequestTypeDef = TypedDict(
-    "CreateKeyspaceRequestRequestTypeDef",
+_RequiredCreateKeyspaceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateKeyspaceRequestRequestTypeDef",
     {
         "keyspaceName": str,
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateKeyspaceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateKeyspaceRequestRequestTypeDef",
+    {
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateKeyspaceRequestRequestTypeDef(
+    _RequiredCreateKeyspaceRequestRequestTypeDef, _OptionalCreateKeyspaceRequestRequestTypeDef
+):
+    pass
+
 
 CreateKeyspaceResponseTypeDef = TypedDict(
     "CreateKeyspaceResponseTypeDef",
@@ -138,21 +177,34 @@ CreateKeyspaceResponseTypeDef = TypedDict(
     },
 )
 
-CreateTableRequestRequestTypeDef = TypedDict(
-    "CreateTableRequestRequestTypeDef",
+_RequiredCreateTableRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateTableRequestRequestTypeDef",
     {
         "keyspaceName": str,
         "tableName": str,
         "schemaDefinition": "SchemaDefinitionTypeDef",
-        "comment": NotRequired["CommentTypeDef"],
-        "capacitySpecification": NotRequired["CapacitySpecificationTypeDef"],
-        "encryptionSpecification": NotRequired["EncryptionSpecificationTypeDef"],
-        "pointInTimeRecovery": NotRequired["PointInTimeRecoveryTypeDef"],
-        "ttl": NotRequired["TimeToLiveTypeDef"],
-        "defaultTimeToLive": NotRequired[int],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateTableRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateTableRequestRequestTypeDef",
+    {
+        "comment": "CommentTypeDef",
+        "capacitySpecification": "CapacitySpecificationTypeDef",
+        "encryptionSpecification": "EncryptionSpecificationTypeDef",
+        "pointInTimeRecovery": "PointInTimeRecoveryTypeDef",
+        "ttl": "TimeToLiveTypeDef",
+        "defaultTimeToLive": int,
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateTableRequestRequestTypeDef(
+    _RequiredCreateTableRequestRequestTypeDef, _OptionalCreateTableRequestRequestTypeDef
+):
+    pass
+
 
 CreateTableResponseTypeDef = TypedDict(
     "CreateTableResponseTypeDef",
@@ -177,13 +229,26 @@ DeleteTableRequestRequestTypeDef = TypedDict(
     },
 )
 
-EncryptionSpecificationTypeDef = TypedDict(
-    "EncryptionSpecificationTypeDef",
+_RequiredEncryptionSpecificationTypeDef = TypedDict(
+    "_RequiredEncryptionSpecificationTypeDef",
     {
         "type": EncryptionTypeType,
-        "kmsKeyIdentifier": NotRequired[str],
     },
 )
+_OptionalEncryptionSpecificationTypeDef = TypedDict(
+    "_OptionalEncryptionSpecificationTypeDef",
+    {
+        "kmsKeyIdentifier": str,
+    },
+    total=False,
+)
+
+
+class EncryptionSpecificationTypeDef(
+    _RequiredEncryptionSpecificationTypeDef, _OptionalEncryptionSpecificationTypeDef
+):
+    pass
+
 
 GetKeyspaceRequestRequestTypeDef = TypedDict(
     "GetKeyspaceRequestRequestTypeDef",
@@ -239,16 +304,18 @@ KeyspaceSummaryTypeDef = TypedDict(
 ListKeyspacesRequestListKeyspacesPaginateTypeDef = TypedDict(
     "ListKeyspacesRequestListKeyspacesPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListKeyspacesRequestRequestTypeDef = TypedDict(
     "ListKeyspacesRequestRequestTypeDef",
     {
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
+        "nextToken": str,
+        "maxResults": int,
     },
+    total=False,
 )
 
 ListKeyspacesResponseTypeDef = TypedDict(
@@ -260,22 +327,49 @@ ListKeyspacesResponseTypeDef = TypedDict(
     },
 )
 
-ListTablesRequestListTablesPaginateTypeDef = TypedDict(
-    "ListTablesRequestListTablesPaginateTypeDef",
+_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_RequiredListTablesRequestListTablesPaginateTypeDef",
     {
         "keyspaceName": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_OptionalListTablesRequestListTablesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListTablesRequestRequestTypeDef = TypedDict(
-    "ListTablesRequestRequestTypeDef",
+
+class ListTablesRequestListTablesPaginateTypeDef(
+    _RequiredListTablesRequestListTablesPaginateTypeDef,
+    _OptionalListTablesRequestListTablesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListTablesRequestRequestTypeDef = TypedDict(
+    "_RequiredListTablesRequestRequestTypeDef",
     {
         "keyspaceName": str,
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
     },
 )
+_OptionalListTablesRequestRequestTypeDef = TypedDict(
+    "_OptionalListTablesRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListTablesRequestRequestTypeDef(
+    _RequiredListTablesRequestRequestTypeDef, _OptionalListTablesRequestRequestTypeDef
+):
+    pass
+
 
 ListTablesResponseTypeDef = TypedDict(
     "ListTablesResponseTypeDef",
@@ -286,22 +380,50 @@ ListTablesResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
-    "ListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
     {
         "resourceArn": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
+
+class ListTagsForResourceRequestListTagsForResourcePaginateTypeDef(
+    _RequiredListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+    _OptionalListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
+):
+    pass
+
+
+_RequiredListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_RequiredListTagsForResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "nextToken": NotRequired[str],
-        "maxResults": NotRequired[int],
     },
 )
+_OptionalListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "_OptionalListTagsForResourceRequestRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceRequestRequestTypeDef(
+    _RequiredListTagsForResourceRequestRequestTypeDef,
+    _OptionalListTagsForResourceRequestRequestTypeDef,
+):
+    pass
+
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
@@ -315,10 +437,11 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PartitionKeyTypeDef = TypedDict(
@@ -328,13 +451,26 @@ PartitionKeyTypeDef = TypedDict(
     },
 )
 
-PointInTimeRecoverySummaryTypeDef = TypedDict(
-    "PointInTimeRecoverySummaryTypeDef",
+_RequiredPointInTimeRecoverySummaryTypeDef = TypedDict(
+    "_RequiredPointInTimeRecoverySummaryTypeDef",
     {
         "status": PointInTimeRecoveryStatusType,
-        "earliestRestorableTimestamp": NotRequired[datetime],
     },
 )
+_OptionalPointInTimeRecoverySummaryTypeDef = TypedDict(
+    "_OptionalPointInTimeRecoverySummaryTypeDef",
+    {
+        "earliestRestorableTimestamp": datetime,
+    },
+    total=False,
+)
+
+
+class PointInTimeRecoverySummaryTypeDef(
+    _RequiredPointInTimeRecoverySummaryTypeDef, _OptionalPointInTimeRecoverySummaryTypeDef
+):
+    pass
+
 
 PointInTimeRecoveryTypeDef = TypedDict(
     "PointInTimeRecoveryTypeDef",
@@ -354,20 +490,33 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-RestoreTableRequestRequestTypeDef = TypedDict(
-    "RestoreTableRequestRequestTypeDef",
+_RequiredRestoreTableRequestRequestTypeDef = TypedDict(
+    "_RequiredRestoreTableRequestRequestTypeDef",
     {
         "sourceKeyspaceName": str,
         "sourceTableName": str,
         "targetKeyspaceName": str,
         "targetTableName": str,
-        "restoreTimestamp": NotRequired[Union[datetime, str]],
-        "capacitySpecificationOverride": NotRequired["CapacitySpecificationTypeDef"],
-        "encryptionSpecificationOverride": NotRequired["EncryptionSpecificationTypeDef"],
-        "pointInTimeRecoveryOverride": NotRequired["PointInTimeRecoveryTypeDef"],
-        "tagsOverride": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalRestoreTableRequestRequestTypeDef = TypedDict(
+    "_OptionalRestoreTableRequestRequestTypeDef",
+    {
+        "restoreTimestamp": Union[datetime, str],
+        "capacitySpecificationOverride": "CapacitySpecificationTypeDef",
+        "encryptionSpecificationOverride": "EncryptionSpecificationTypeDef",
+        "pointInTimeRecoveryOverride": "PointInTimeRecoveryTypeDef",
+        "tagsOverride": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class RestoreTableRequestRequestTypeDef(
+    _RequiredRestoreTableRequestRequestTypeDef, _OptionalRestoreTableRequestRequestTypeDef
+):
+    pass
+
 
 RestoreTableResponseTypeDef = TypedDict(
     "RestoreTableResponseTypeDef",
@@ -377,15 +526,26 @@ RestoreTableResponseTypeDef = TypedDict(
     },
 )
 
-SchemaDefinitionTypeDef = TypedDict(
-    "SchemaDefinitionTypeDef",
+_RequiredSchemaDefinitionTypeDef = TypedDict(
+    "_RequiredSchemaDefinitionTypeDef",
     {
         "allColumns": Sequence["ColumnDefinitionTypeDef"],
         "partitionKeys": Sequence["PartitionKeyTypeDef"],
-        "clusteringKeys": NotRequired[Sequence["ClusteringKeyTypeDef"]],
-        "staticColumns": NotRequired[Sequence["StaticColumnTypeDef"]],
     },
 )
+_OptionalSchemaDefinitionTypeDef = TypedDict(
+    "_OptionalSchemaDefinitionTypeDef",
+    {
+        "clusteringKeys": Sequence["ClusteringKeyTypeDef"],
+        "staticColumns": Sequence["StaticColumnTypeDef"],
+    },
+    total=False,
+)
+
+
+class SchemaDefinitionTypeDef(_RequiredSchemaDefinitionTypeDef, _OptionalSchemaDefinitionTypeDef):
+    pass
+
 
 StaticColumnTypeDef = TypedDict(
     "StaticColumnTypeDef",
@@ -434,19 +594,32 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateTableRequestRequestTypeDef = TypedDict(
-    "UpdateTableRequestRequestTypeDef",
+_RequiredUpdateTableRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateTableRequestRequestTypeDef",
     {
         "keyspaceName": str,
         "tableName": str,
-        "addColumns": NotRequired[Sequence["ColumnDefinitionTypeDef"]],
-        "capacitySpecification": NotRequired["CapacitySpecificationTypeDef"],
-        "encryptionSpecification": NotRequired["EncryptionSpecificationTypeDef"],
-        "pointInTimeRecovery": NotRequired["PointInTimeRecoveryTypeDef"],
-        "ttl": NotRequired["TimeToLiveTypeDef"],
-        "defaultTimeToLive": NotRequired[int],
     },
 )
+_OptionalUpdateTableRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateTableRequestRequestTypeDef",
+    {
+        "addColumns": Sequence["ColumnDefinitionTypeDef"],
+        "capacitySpecification": "CapacitySpecificationTypeDef",
+        "encryptionSpecification": "EncryptionSpecificationTypeDef",
+        "pointInTimeRecovery": "PointInTimeRecoveryTypeDef",
+        "ttl": "TimeToLiveTypeDef",
+        "defaultTimeToLive": int,
+    },
+    total=False,
+)
+
+
+class UpdateTableRequestRequestTypeDef(
+    _RequiredUpdateTableRequestRequestTypeDef, _OptionalUpdateTableRequestRequestTypeDef
+):
+    pass
+
 
 UpdateTableResponseTypeDef = TypedDict(
     "UpdateTableResponseTypeDef",
